import React__default,{useCallback}from'react';import {useParams}from'@remix-run/react';import {isEmpty}from'lodash-es';import {Form,Spin,message}from'antd';import {generateResourceUri,IConfigCollectionName,IntegrationsConfigSteps}from'@adminide-stack/core';import {useUpsertProjectThroughIntegrationMutation,useUpsertTaskThroughIntegrationMutation,useUpsertTagThroughIntegrationMutation}from'@adminide-stack/project-mgmt-core';import {useSetting}from'@adminide-stack/platform-client';import {logger}from'@common-stack/client-core';import {ProjectValidationStatus,ConfigureProject}from'./ConfigureProject.js';import {Initialize}from'./Initialize.js';import {SelectGithubProcess,ConfigWith}from'./SelectGithubProcess.js';import {SelectCommon}from'./SelectCommon.js';import {SelectMultiple}from'./SelectMultiple.js';const IntegrationConfigCommon = props => {
  const defaultIdentifierKey = 'id';
  const {
    currentStep,
    footer,
    integrationConfiguration,
    stepsDispatch,
    workspaces: {
      workspaces,
      fetchWorkspaces,
      workspacesLoading,
      workspacesIdentifierKey = defaultIdentifierKey
    },
    projects: {
      projects,
      fetchProjects,
      projectsLoading,
      projectsIdentifierKey = defaultIdentifierKey
    },
    repositories: {
      repositories,
      fetchRepositories,
      repoLoading,
      repositoriesIdentifierKey = defaultIdentifierKey
    },
    teams: {
      teams,
      fetchTeams,
      teamsLoading,
      teamsIdentifierKey = '_id'
    },
    tasks: {
      tasks,
      tasksLoading,
      fetchTasks,
      tasksIdentifierKey = defaultIdentifierKey
    },
    tags: {
      fetchTags
    }
  } = props;
  const {
    orgName
  } = useParams();
  const [upsertProject] = useUpsertProjectThroughIntegrationMutation();
  const [upsertTask] = useUpsertTaskThroughIntegrationMutation();
  const [upsertTag] = useUpsertTagThroughIntegrationMutation();
  const {
    updateConfiguration
  } = useSetting({
    configKey: ''
  });
  const [isValidRecord, setIsValidRecord] = React__default.useState(ProjectValidationStatus.Success);
  const [isNextBtnDisabled, disableNextBtn] = React__default.useState(false);
  const [projectForm] = Form.useForm();
  const stepsValue = integrationConfiguration?.integrationInfo;
  React__default.useEffect(() => {
    if (tasks && integrationConfiguration) {
      // stepsDispatch({
      //   type: 'taskList',
      //   payload: tasks
      // });
      const overrides = {
        resource: generateResourceUri(IConfigCollectionName.IntegrationWorkflow, {
          name: integrationConfiguration.name,
          orgName
        }, 'settings')
      };
      updateConfiguration({
        updateKey: 'organization.integration.[github].git.taskList',
        updateOverrides: overrides,
        value: tasks.slice(0),
        target: 5 /* ConfigurationTarget.ORGANIZATION_RESOURCE */
      });
    }
  }, [tasks, integrationConfiguration]);
  const nextBtnDisabled = useCallback(() => {
    if (currentStep === IntegrationsConfigSteps.Workspaces && isEmpty(stepsValue?.workspace)) {
      return true;
    } else if (currentStep === IntegrationsConfigSteps.Initialize) {
      return isNextBtnDisabled || isEmpty(integrationConfiguration?.name);
    } else if (currentStep === IntegrationsConfigSteps.Projects && isEmpty(stepsValue?.repository) && isEmpty(stepsValue?.project)) {
      return true;
    } else if (currentStep === IntegrationsConfigSteps.Teams && isEmpty(stepsValue?.team) && !stepsValue?.tasks?.length) {
      return true;
    } else {
      return false;
    }
  }, [integrationConfiguration, currentStep, stepsValue, isNextBtnDisabled]);
  const saveBtnDisabled = useCallback(() => {
    if (currentStep === IntegrationsConfigSteps.ConfigureProject) {
      const {
        project
      } = projectForm.getFieldsValue();
      return !(project && isValidRecord === ProjectValidationStatus.Success);
    }
  }, [currentStep, isValidRecord]);
  const saveBillingConfiguration = (projectName, billableValue) => {
    const overrides = {
      resource: generateResourceUri(IConfigCollectionName.Projects, {
        name: projectName,
        orgName
      }, 'settings')
    };
    void updateConfiguration({
      updateKey: 'organization.project.billable',
      updateOverrides: overrides,
      value: billableValue || false,
      target: 5 /* ConfigurationTarget.ORGANIZATION_RESOURCE */
    });
  };
  const saveIntegrationConfiguration = project => {
    const overrides = {
      resource: generateResourceUri(IConfigCollectionName.Projects, {
        name: project,
        orgName
      }, 'settings')
    };
    updateConfiguration({
      updateKey: 'organization.project.integration.configurationId',
      updateOverrides: overrides,
      value: integrationConfiguration?.id,
      target: 5 /* ConfigurationTarget.ORGANIZATION_RESOURCE */
    });
    updateConfiguration({
      updateKey: 'organization.project.integration.type',
      updateOverrides: overrides,
      value: 'Github',
      target: 5 /* ConfigurationTarget.ORGANIZATION_RESOURCE */
    });
    updateConfiguration({
      updateKey: 'organization.project.integration.status',
      updateOverrides: overrides,
      value: 'Active',
      target: 5 /* ConfigurationTarget.ORGANIZATION_RESOURCE */
    });
  };
  const fetchProjectPayload = (projectName, clientId) => {
    return {
      name: projectName,
      clientId: clientId,
      teams: stepsValue?.team?.id ? [stepsValue?.team?.id] : [],
      createdBy: 'GITHUB-INTEGRATION'
    };
  };
  const onSave = async () => {
    try {
      const {
        project,
        client,
        billable
      } = await projectForm.validateFields();
      const payload = fetchProjectPayload(project, client);
      upsertProject({
        variables: {
          where: {
            name: project
          },
          project: payload
        },
        update: (cache, {
          data,
          errors
        }) => {
          if (stepsValue.tasks) {
            stepsValue.tasks.forEach(item => {
              upsertTask({
                variables: {
                  where: {
                    taskName: item.name,
                    projectId: data?.upsertProjectThroughIntegration.id
                  },
                  task: {
                    taskName: item.name,
                    projectId: data?.upsertProjectThroughIntegration.id
                  }
                },
                update: (cache, {
                  data,
                  errors
                }) => {
                  cache.modify({
                    fields: {
                      getTasks() {}
                    }
                  });
                }
              });
            });
          }
          if (stepsValue.tags) {
            stepsValue.tags.forEach(item => {
              upsertTag({
                variables: {
                  where: {
                    tagName: item.name,
                    projectId: data?.upsertProjectThroughIntegration.id
                  },
                  tag: {
                    tagName: item.name,
                    projectId: data?.upsertProjectThroughIntegration.id
                  }
                },
                update: (cache, {
                  data,
                  errors
                }) => {
                  cache.modify({
                    fields: {
                      getTags() {}
                    }
                  });
                }
              });
            });
          }
          saveIntegrationConfiguration(project);
          cache.modify({
            fields: {
              getProjects() {}
            }
          });
        }
      });
      saveBillingConfiguration(project, billable);
      message.success('Project Created Successfully!');
    } catch (e) {
      logger.error(e);
    }
  };
  return integrationConfiguration?.integrationName ? React__default.createElement(React__default.Fragment, null, currentStep === IntegrationsConfigSteps.Initialize && React__default.createElement(Initialize, {
    integrationConfiguration: integrationConfiguration,
    disableNextBtn: disableNextBtn,
    stepsDispatch: stepsDispatch
  }), currentStep === IntegrationsConfigSteps.Workspaces && React__default.createElement(SelectCommon, {
    title: 'Choose your workspace',
    placeholder: "Select Workspace",
    selectedItem: stepsValue?.workspace,
    setSelectedItem: payload => stepsDispatch({
      type: 'workspace',
      payload
    }),
    loading: workspacesLoading,
    data: workspaces || [],
    fetchData: fetchWorkspaces,
    identifier: workspacesIdentifierKey
  }), currentStep === IntegrationsConfigSteps.SelectIntegration && React__default.createElement(SelectGithubProcess, {
    selectedItem: stepsValue?.configWith,
    setSelectedItem: payload => stepsDispatch({
      type: 'configWith',
      payload
    })
  }), currentStep === IntegrationsConfigSteps.Projects && (stepsValue?.configWith === ConfigWith.Project ? React__default.createElement(SelectCommon, {
    placeholder: "Select project",
    title: `Choose your project from ${stepsValue?.workspace?.name}`,
    selectedItem: stepsValue?.project,
    setSelectedItem: payload => stepsDispatch({
      type: 'project',
      payload
    }),
    loading: projectsLoading,
    identifier: projectsIdentifierKey,
    data: projects || [],
    fetchData: () => fetchProjects(stepsValue?.workspace)
  }) : React__default.createElement(SelectCommon, {
    placeholder: "Select repository",
    title: `Choose your repository from ${stepsValue?.workspace?.name}`,
    selectedItem: stepsValue?.repository,
    setSelectedItem: payload => stepsDispatch({
      type: 'repository',
      payload
    }),
    loading: repoLoading,
    identifier: repositoriesIdentifierKey,
    data: repositories || [],
    fetchData: () => fetchRepositories(stepsValue?.workspace)
  })), currentStep === IntegrationsConfigSteps.Teams && (stepsValue?.configWith === ConfigWith.Project ? React__default.createElement(SelectCommon, {
    placeholder: "Select Teams",
    title: "Select team from the list below",
    fetchData: fetchTeams,
    data: teams || [],
    loading: teamsLoading,
    selectedItem: stepsValue?.team,
    identifier: teamsIdentifierKey,
    setSelectedItem: payload => stepsDispatch({
      type: 'team',
      payload
    })
  }) : React__default.createElement(SelectMultiple, {
    placeholder: "Select Task",
    title: "Select task from the list below",
    fetchData: () => {
      fetchTasks(stepsValue?.workspace, stepsValue?.repository);
      fetchTags(stepsValue?.workspace, stepsValue?.repository);
    },
    data: tasks || [],
    loading: tasksLoading,
    selectedItems: stepsValue?.tasks,
    identifier: tasksIdentifierKey,
    setSelectedItem: payload => stepsDispatch({
      type: 'tasks',
      payload
    })
  })), currentStep === IntegrationsConfigSteps.ConfigureProject && React__default.createElement(ConfigureProject, {
    projectForm: projectForm,
    integrationProjectName: stepsValue?.project?.name || stepsValue?.repository?.name,
    integrationName: integrationConfiguration?.integrationName,
    isValidRecord: isValidRecord,
    setIsValidRecord: setIsValidRecord,
    stepsDispatch: stepsDispatch,
    orgName: orgName
  }), footer && footer({
    onSave,
    nextBtnDisabled,
    saveBtnDisabled
  })) : React__default.createElement(Spin, null);
};export{IntegrationConfigCommon};//# sourceMappingURL=IntegrationConfigCommon.js.map
