import*as React from'react';import {useState,useLayoutEffect}from'react';import {useLocation,Route}from'@remix-run/react';import {Fill,Slot}from'@common-stack/components-pro';import {registerRouteBasePlugin,unregisterRouteBasePlugin,RouteBasedPluginArea}from'@common-stack/client-react';const prepareFill = fill => {
  const {
    name,
    Component
  } = fill;
  return React.createElement(Fill, {
    name: name
  }, fillProps => React.createElement(Component, {
    ...fillProps
  }));
};
/**
 * Route base Plugin Area, to render Slot/Fill dynamically base on the route, this component will read the current route
 * of the application and read the fill name from the path and render that slot e.g  if you need to render a slot with the name
 * 'integration-fill' on a page with the path "/account/git/integration-fill" then you need to pass basePath='/account/git/'
 * and a fill with name `integration-fill` in fillsToRegister array, the component will automatically read the fill name from the
 * route and register the appropriate fill and render the appropriate slot for you.
 *
 * @param {IWithPluginArea} props
 * @constructor
 */
const WithPluginArea = props => {
  const {
    baseRoute,
    fillsToRegister,
    shouldRenderRoutes = true
  } = props;
  const [registerFill, setRegisterFill] = useState();
  const location = useLocation();
  // Register and Unregister single Fill base on the current Path, this is to avoid registering any unnecessary
  // Fill/plugin
  useLayoutEffect(() => {
    const {
      pathname
    } = location;
    const fillName = pathname.split('/').pop();
    const fillToRegister = fillsToRegister.find(({
      name
    }) => name === fillName);
    if (fillToRegister) {
      registerRouteBasePlugin(fillToRegister.name, {
        ...fillToRegister,
        render: () => prepareFill(fillToRegister)
      });
      setRegisterFill(fillToRegister);
    }
    // Un register Fill/plugin on Unmount
    return () => {
      if (registerFill) {
        unregisterRouteBasePlugin(registerFill.name);
        setRegisterFill(undefined);
      }
    };
  }, [history]);
  // Render the component only when a plugin has been registered
  if (!registerFill) {
    return React.createElement(React.Fragment, null);
  }
  return React.createElement(React.Fragment, null, React.createElement(RouteBasedPluginArea, null), shouldRenderRoutes && fillsToRegister.map(fill => {
    const SlotComponent = () => React.createElement(Slot, {
      name: fill.name,
      fillProps: {
        active: true
      }
    });
    return React.createElement(Route, {
      key: fill.name,
      path: `${baseRoute}${fill.name}`,
      element: React.createElement(SlotComponent, null)
    });
  }));
};export{WithPluginArea};//# sourceMappingURL=WithPluginArea.js.map
