import { Observable, Observer } from 'rxjs';
/**
 * Returns a functiont that will trigger an error on the next render,
 * which can be caught by an ErrorBoundary higher up in the component tree.
 */
export declare function useError(): (error: any) => void;
/**
 * React hook to get the latest value of an Observable.
 * Will return `undefined` if the Observable didn't emit yet.
 * If the Observable errors, will throw an error that can be caught with `try`/`cactch` or with an React error boundary.
 * The Observable is subscribed on the first render and unsubscribed on unmount or whenever it changes (wrap it in `useMemo()`) to make sure it is not resubscribed on every render.
 *
 * @param observable The Observable to subscribe to. If this is the return value of a function, you should use `useMemo()` to make sure it is not resubscribed on every render.
 * @throws If the Observable pipeline errors.
 */
export declare function useObservable<T>(observable: Observable<T>): T | undefined;
/**
 * A React hook to handle a React event with an RxJS pipeline.
 *
 * @template T The event type.
 * @template R The result type.
 * @param transform an RxJS operator pipeline that is passed an Observable of
 * the events triggered on the next function and can transform it to values of
 * which the latest one is returned. **You need to wrap this callback with `useCallback()`**.
 * @returns A next function to be used in JSX as an event handler, and the latest result of Observable pipeline.
 * @throws If the Observable pipeline errors.
 */
export declare function useEventObservable<T, R>(transform: (events: Observable<T>) => Observable<R>): [Observer<T>['next'], R | undefined];
export declare function useEventObservable<R>(transform: (events: Observable<void>) => Observable<R>): [() => void, R | undefined];
